==> jc-1.4.0.tar.gz: javax/swing/text/DefaultEditorKit__24InsertBreakAction.h <==
// public class javax.swing.text.DefaultEditorKit$InsertBreakAction

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f02353a2de7b0e85 javax_swing_AbstractAction
// @dep_class 20de4f87908e85c1 javax_swing_text_DefaultEditorKit__24InsertBreakAction
// @dep_class ebc1c295cb90fd47 javax_swing_text_TextAction

// header file dependencies
// @dep_header javax_swing_text_TextAction

#include "javax/swing/text/TextAction.h"

#ifndef _JC_javax_swing_text_DefaultEditorKit__24InsertBreakAction_H_
#define _JC_javax_swing_text_DefaultEditorKit__24InsertBreakAction_H_

// Forward structure declarations
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$sub_refs	_jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$sub_refs;
typedef struct _jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$sub_nonrefs	_jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$sub_nonrefs;
typedef struct _jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$refs	_jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$refs;
typedef struct _jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$nonrefs	_jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$nonrefs;
typedef struct _jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$object	_jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$object;

typedef const struct _jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$vmethods	_jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$vmethods;
typedef const struct _jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$vtable	_jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$vtable;
typedef const struct _jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$vtype	_jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$vtype;

// Constructors
extern void _jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$object *);

// Virtual methods
extern void _jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$method$actionPerformed$9046a9754e643ffd(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$object *, struct _jc_java_awt_event_ActionEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$method_info$actionPerformed$9046a9754e643ffd;

// Virtual methods structure
struct _jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$vmethods {
	void	(*actionPerformed$9046a9754e643ffd)(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$object *, struct _jc_java_awt_event_ActionEvent$object *);
};

// Vtable
struct _jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_AbstractAction$vmethods	javax_swing_AbstractAction;
	_jc_javax_swing_text_TextAction$vmethods	javax_swing_text_TextAction;
	_jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$vmethods	javax_swing_text_DefaultEditorKit__24InsertBreakAction;
};

// Vtype
struct _jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$vtype {
	_jc_type			type;
	_jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$refs {
    _jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$sub_refs	javax_swing_text_DefaultEditorKit__24InsertBreakAction;
    _jc_javax_swing_text_TextAction$sub_refs	javax_swing_text_TextAction;
    _jc_javax_swing_AbstractAction$sub_refs	javax_swing_AbstractAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_AbstractAction$sub_nonrefs	javax_swing_AbstractAction;
    _jc_javax_swing_text_TextAction$sub_nonrefs	javax_swing_text_TextAction;
    _jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$sub_nonrefs	javax_swing_text_DefaultEditorKit__24InsertBreakAction;
};

// Object instance structure
struct _jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$object {
	_jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$vtype	*vtype;
	_jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$vtype _jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_DefaultEditorKit__24InsertBreakAction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$class_object;

#endif	/* _JC_javax_swing_text_DefaultEditorKit__24InsertBreakAction_H_ */

==> jc-1.4.5.tar.gz: javax/swing/text/DefaultEditorKit__24InsertBreakAction.h <==
// public class javax.swing.text.DefaultEditorKit$InsertBreakAction

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f02353a2de7b0e85 javax_swing_AbstractAction
// @dep_class 2927296dc23c8987 javax_swing_text_DefaultEditorKit__24InsertBreakAction
// @dep_class ebc1c295cb90fd47 javax_swing_text_TextAction

// header file dependencies
// @dep_header javax_swing_text_TextAction

#include "javax/swing/text/TextAction.h"

#ifndef _JC_javax_swing_text_DefaultEditorKit__24InsertBreakAction_H_
#define _JC_javax_swing_text_DefaultEditorKit__24InsertBreakAction_H_

// Forward structure declarations
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$sub_refs	_jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$sub_refs;
typedef struct _jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$sub_nonrefs	_jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$sub_nonrefs;
typedef struct _jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$refs	_jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$refs;
typedef struct _jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$nonrefs	_jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$nonrefs;
typedef struct _jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$object	_jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$object;

typedef const struct _jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$vmethods	_jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$vmethods;
typedef const struct _jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$vtable	_jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$vtable;
typedef const struct _jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$vtype	_jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$vtype;

// Constructors
extern void _jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$method$actionPerformed$9046a9754e643ffd(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$method_info$actionPerformed$9046a9754e643ffd;

// Virtual methods structure
struct _jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$vmethods {
	void	(*actionPerformed$9046a9754e643ffd)(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_AbstractAction$vmethods	javax_swing_AbstractAction;
	_jc_javax_swing_text_TextAction$vmethods	javax_swing_text_TextAction;
	_jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$vmethods	javax_swing_text_DefaultEditorKit__24InsertBreakAction;
};

// Vtype
struct _jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$vtype {
	_jc_type			type;
	_jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$refs {
    _jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$sub_refs	javax_swing_text_DefaultEditorKit__24InsertBreakAction;
    _jc_javax_swing_text_TextAction$sub_refs	javax_swing_text_TextAction;
    _jc_javax_swing_AbstractAction$sub_refs	javax_swing_AbstractAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_AbstractAction$sub_nonrefs	javax_swing_AbstractAction;
    _jc_javax_swing_text_TextAction$sub_nonrefs	javax_swing_text_TextAction;
    _jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$sub_nonrefs	javax_swing_text_DefaultEditorKit__24InsertBreakAction;
};

// Object instance structure
struct _jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$object {
	_jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$vtype	*vtype;
	_jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$vtype _jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_DefaultEditorKit__24InsertBreakAction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_DefaultEditorKit__24InsertBreakAction$class_object;

#endif	/* _JC_javax_swing_text_DefaultEditorKit__24InsertBreakAction_H_ */
